@@ -12,7 +12,7 @@ from matplotlib.figure import Figure
 from matplotlib.patches import Patch
 from matplotlib.projections.polar import PolarAxes
 
-from pycirclize import config
+from pycirclize import config, utils
 from pycirclize.parser import Bed
 from pycirclize.patches import ArcLine, ArcRectangle, BezierCurve
 from pycirclize.sector import Sector
@@ -27,8 +27,8 @@ class Circos:
         sectors: dict[str, int] | dict[str, float],
         start: float = 0,
         end: float = 360,
-        # TODO: Enable set list of space
-        space: float = 0,
+        *,
+        space: float | list[float] = 0,
         endspace: bool = True,
         sectors_start_pos: dict[str, int] | dict[str, float] = {},
         show_axis_for_debug: bool = False,
@@ -43,7 +43,7 @@ class Circos:
         end : float, optional
             Plot end degree (`-360 <= start < end <= 360`)
         space : float | list[float], optional
-            Space degree between sector
+            Space degree(s) between sector
         endspace : bool, optional
             If True, insert space after the end sector
         sectors_start_pos : dict[str, int] | dict[str, float], optional
@@ -58,22 +58,28 @@ class Circos:
         whole_deg_size = end - start
         space_num = len(sectors) if endspace else len(sectors) - 1
         if isinstance(space, (list, tuple)):
+            if len(space) != space_num:
+                err_msg = f"{space=} is invalid.\n"
+                err_msg += f"Length of space list must be {space_num}."
+                raise ValueError(err_msg)
+            space_list = list(space) + [0]
             space_deg_size = sum(space)
         else:
             space_deg_size = space * space_num
+            space_list = [space] * space_num + [0]
         whole_deg_size_without_space = whole_deg_size - space_deg_size
-        total_size = sum(sectors.values())
+        sector_total_size = sum(sectors.values())
 
         rad_pos = math.radians(start)
         self._sectors: list[Sector] = []
-        for name, size in sectors.items():
-            size_ratio = size / total_size
-            deg_size = whole_deg_size_without_space * size_ratio
+        for idx, (sector_name, sector_size) in enumerate(sectors.items()):
+            sector_size_ratio = sector_size / sector_total_size
+            deg_size = whole_deg_size_without_space * sector_size_ratio
             rad_size = math.radians(deg_size)
             rad_lim = (rad_pos, rad_pos + rad_size)
-            rad_pos += rad_size + math.radians(space)
-            start_pos = sectors_start_pos.get(name, 0)
-            sector = Sector(name, size, rad_lim, start_pos)
+            rad_pos += rad_size + math.radians(space_list[idx])
+            start_pos = sectors_start_pos.get(sector_name, 0)
+            sector = Sector(sector_name, sector_size, rad_lim, start_pos)
             self._sectors.append(sector)
 
         self._deg_lim = (start, end)
@@ -89,7 +95,7 @@ class Circos:
     @property
     def rad_size(self) -> float:
         """Radian size"""
-        return self.rad_lim[1] - self.rad_lim[0]
+        return max(self.rad_lim) - min(self.rad_lim)
 
     @property
     def rad_lim(self) -> tuple[float, float]:
@@ -99,7 +105,7 @@ class Circos:
     @property
     def deg_size(self) -> float:
         """Degree size"""
-        return self.deg_lim[1] - self.deg_lim[0]
+        return max(self.deg_lim) - min(self.deg_lim)
 
     @property
     def deg_lim(self) -> tuple[float, float]:
@@ -129,7 +135,8 @@ class Circos:
         bed_file: str | Path,
         start: float = 0,
         end: float = 360,
-        space: float = 0,
+        *,
+        space: float | list[float] = 0,
         endspace: bool = True,
     ) -> Circos:
         """Initialize Circos instance from BED file
@@ -144,8 +151,8 @@ class Circos:
             Plot start degree (-360 <= start < end <= 360)
         end : float, optional
             Plot end degree (-360 <= start < end <= 360)
-        space : float, optional
-            Space degree between sector
+        space : float | list[float], optional
+            Space degree(s) between sector
         endspace : bool, optional
             If True, insert space after the end sector
 
@@ -157,12 +164,20 @@ class Circos:
         records = Bed(bed_file).records
         sectors = {rec.chr: rec.size for rec in records}
         sectors_start_pos = {rec.chr: rec.start for rec in records}
-        return Circos(sectors, start, end, space, endspace, sectors_start_pos)
+        return Circos(
+            sectors,
+            start,
+            end,
+            space=space,
+            endspace=endspace,
+            sectors_start_pos=sectors_start_pos,
+        )
 
     def add_cytoband_tracks(
         self,
         r_lim: tuple[float, float],
         cytoband_file: str | Path,
+        *,
         track_name: str = "cytoband",
         cytoband_cmap: dict[str, str] | None = None,
     ) -> None:
@@ -171,7 +186,7 @@ class Circos:
         Parameters
         ----------
         r_lim : tuple[float, float]
-            Radius limit region (0 <= r <= 100)
+            Radius limit region (0 - 100)
         cytoband_file : str | Path
             Cytoband tsv file (UCSC format)
         track_name : str, optional
@@ -206,30 +221,51 @@ class Circos:
         """
         name2sector = {s.name: s for s in self.sectors}
         if name not in name2sector:
-            raise ValueError(f"SectorName='{name}' not found.")
+            raise ValueError(f"{name=} sector not found.")
         return name2sector[name]
 
+    def axis(self, **kwargs) -> None:
+        """Plot axis
+
+        By default, simple black axis params(`fc="none", ec="black", lw=0.5`) are set.
+
+        Parameters
+        ----------
+        **kwargs : dict, optional
+            Patch properties (e.g. `fc="red", ec="blue", lw=0.5, ...`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
+        """
+        # Set default params
+        kwargs = utils.plot.set_axis_default_kwargs(**kwargs)
+
+        # Axis facecolor placed behind other patches (zorder=0.99)
+        fc_behind_kwargs = {**kwargs, **config.AXIS_FACE_PARAM}
+        self.rect(**fc_behind_kwargs)
+
+        # Axis edgecolor placed in front of other patches (zorder=1.01)
+        ec_front_kwargs = {**kwargs, **config.AXIS_EDGE_PARAM}
+        self.rect(**ec_front_kwargs)
+
     def text(
         self,
         text: str,
-        deg: float = 0,
         r: float = 0,
+        deg: float = 0,
         **kwargs,
     ) -> None:
         """Plot text
 
-        By default, plot text on circle center
-
         Parameters
         ----------
         text : str
             Text content
-        deg : float
-            Text degree position (0 <= degree <= 360)
         r : float
-            Text radius position
-        **kwargs
+            Radius position
+        deg : float
+            Degree position (0 - 360)
+        **kwargs : dict, optional
             Text properties (e.g. `size=12, color="red", rotation=90, ...`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.text.html>
         """
         if "va" not in kwargs and "verticalalignment" not in kwargs:
             kwargs.update(dict(va="center"))
@@ -247,17 +283,18 @@ class Circos:
         deg_lim: tuple[float, float] | None = None,
         **kwargs,
     ) -> None:
-        """Plot line for circos region
+        """Plot line
 
         Parameters
         ----------
         r : float
-            Line radius position (0 <= r <= 100)
+            Radius position (0 - 100)
         deg_lim : tuple[float, float]
-            Rectangle degree limit region (-360 <= degree <= 360).
+            Degree limit region (-360 - 360).
             If None, start-end degree limit specified by user at initialization is set.
-        **kwargs
+        **kwargs : dict, optional
             Patch properties (e.g. `color="red", lw=3, ...`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         """
         deg_lim = self.deg_lim if deg_lim is None else deg_lim
         rad_lim = (math.radians(min(deg_lim)), math.radians(max(deg_lim)))
@@ -269,17 +306,18 @@ class Circos:
         deg_lim: tuple[float, float] | None = None,
         **kwargs,
     ) -> None:
-        """Plot rectangle for circos region
+        """Plot rectangle
 
         Parameters
         ----------
         r_lim : tuple[float, float]
-            Rectangle radius limit region (0 <= r <= 100)
+            Radius limit region (0 - 100)
         deg_lim : tuple[float, float]
-            Rectangle degree limit region (-360 <= degree <= 360).
+            Degree limit region (-360 - 360).
             If None, start-end degree limit specified by user at initialization is set.
-        **kwargs
+        **kwargs : dict, optional
             Patch properties (e.g. `fc="red", ec="black", lw=1, hatch="//", ...`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         """
         deg_lim = self.deg_lim if deg_lim is None else deg_lim
         rad_lim = (math.radians(min(deg_lim)), math.radians(max(deg_lim)))
@@ -295,6 +333,7 @@ class Circos:
         sector_region2: tuple[str, float, float],
         r1: float | None = None,
         r2: float | None = None,
+        *,
         color: str = "grey",
         alpha: float = 0.5,
         height_ratio: float = 0.5,
@@ -312,28 +351,29 @@ class Circos:
         sector_region2 : tuple[str, float, float]
             Link sector region2 (name, start, end)
         r1 : float | None, optional
-            Link radius end postion for sector_region1.
+            Link radius end position for sector_region1.
             If None, lowest radius of target sector is set.
         r2 : float | None, optional
-            Link radius end postion for sector_region2.
+            Link radius end position for sector_region2.
             If None, lowest radius of target sector is set.
         color : str, optional
             Link color
         alpha : float, optional
             Link color alpha (transparency) value
         height_ratio : float, optional
-            Bezier curve height ratio parameter
+            Bezier curve height ratio
         direction : int, optional
             `0`: No direction edge shape (Default)
             `1`: Forward direction arrow edge shape (region1 -> region2)
-            `-1`: Reverse dirction arrow edge shape (region1 <- region2)
+            `-1`: Reverse direction arrow edge shape (region1 <- region2)
             `2`: Bidirectional arrow edge shape (region1 <-> region2)
         arrow_length_ratio : float, optional
-            Arrow length ratio
+            Direction arrow length ratio
         allow_twist : bool, optional
             If False, twisted link is resolved.
-        **kwargs
-            Patch properties (e.g. `lw=1.0, hatch="//", ...`)
+        **kwargs : dict, optional
+            Patch properties (e.g. `ec="red", lw=1.0, hatch="//", ...`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         """
         # Set data for plot link
         name1, start1, end1 = sector_region1
@@ -446,12 +486,10 @@ class Circos:
         min_deg, max_deg = -360, 360
         if not min_deg <= start < end <= max_deg:
             err_msg = "start-end must be "
-            err_msg += f"'{min_deg} <= start < end <= {max_deg}' "
-            err_msg += f"(start={start}, end={end})"
+            err_msg += f"'{min_deg} <= start < end <= {max_deg}' ({start=}, {end=})"
             raise ValueError(err_msg)
         if end - start > max_deg:
-            err_msg = f"'end - start' must be less than {max_deg} "
-            err_msg += f"(start={start}, end={end})"
+            err_msg = f"'end - start' must be less than {max_deg} ({start=}, {end=})"
             raise ValueError(err_msg)
 
     def _initialize_figure(
@@ -473,9 +511,9 @@ class Circos:
         fig, ax : tuple[Figure, PolarAxes]
             Figure, PolarAxes
         """
-        fig: Figure = plt.figure(figsize=figsize, dpi=dpi, tight_layout=True)
-        ax: PolarAxes = fig.add_subplot(projection="polar")
-        return fig, ax
+        fig = plt.figure(figsize=figsize, dpi=dpi, tight_layout=True)
+        ax = fig.add_subplot(projection="polar")
+        return fig, ax  # type: ignore
 
     def _initialize_polar_axes(self, ax: PolarAxes) -> None:
         """Initialize polar axes params
